Summary: The Xenomai real-time framework
Name: xenomai
Version: 2.4.2
Release: 1
License: GPL
Group: Development/Kernel
URL: www.xenomai.org
Source0: %{name}-%{version}.tar.bz2
Patch: xenomai-2.4-relsymlinks.patch
Requires(post): kernel-source

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Xenomai is a real-time development framework cooperating with
the Linux kernel, in order to provide a pervasive, interface-agnostic,
hard real-time support to user-space applications, seamlessly
integrated into the GNU/Linux environment.

Xenomai is based on an abstract RTOS core, usable for building any
kind of real-time interfaces, over a nucleus which exports a set
of generic RTOS services. Any number of RTOS personalities called
"skins" can then be built over the nucleus, providing their own
specific interface to the applications, by using the services of a
single generic core to implement it.

The Xenomai project has been launched in August 2001. It has merged in
2003 with the RTAI project to produce an industrial-grade real-time
Free Software platform for GNU/Linux called RTAI/fusion, on top of
Xenomai's abstract RTOS core. Eventually, the RTAI/fusion effort became
independent from RTAI in 2005 as the Xenomai project

%ifarch ppc
%package ppc-kernel
Summary: The Xenomai-enabled kernel for ARCH=ppc
Group: Development/Kernel
Requires(post): kernel-source, xenomai

%description ppc-kernel
Xenomai kernel for ppc architecture
%endif

%prep
%setup -q -n %{name}-%{version}
%patch -p1

%build

./configure --prefix=/usr/local/xenomai --host=%{_targetarch}-linux --build=%{_host}

make

%install
rm -rf $RPM_BUILD_ROOT

make install DESTDIR=$RPM_BUILD_ROOT SUDO=true
rm -rf $RPM_BUILD_ROOT/dev
install -d -m 755  $RPM_BUILD_ROOT/usr/local/xenomai/kbuild
tar cf - ksrc include scripts | \
  (cd $RPM_BUILD_ROOT/usr/local/xenomai/kbuild;tar xpf -)

%clean
rm -rf $RPM_BUILD_ROOT

%post
echo "Configuring Xenomai kernel..."
cwd=`pwd`
PATH=${RUNTIME_PREFIX}/usr/bin:$PATH
export PATH

cd ${RUNTIME_PREFIX}/%{_targetpath}/usr/src
tree=`echo linux-2.6.[0-9]*[0-9]`
if [ -d ${tree}-xenomai ]; then
  echo "${tree}-xenomai exists, not overwriting."
  echo "Xenomai patch was not applied."
  echo "If you want to do it by hand, patches are located at \
    ${RUNTIME_PREFIX}/%{_targetpath}/usr/local/xenomai/kbuild/ksrc/arch/<ARCH>/patches."
  exit 0
fi
cp -a ${tree} ${tree}-xenomai
cd ${tree}-xenomai

%ifarch ppc ppc64
  make ARCH=powerpc mrproper
%else
  make ARCH=%{_targetarch} mrproper
%endif

cd $cwd

# We set CDPATH here because "prepare-kernel.sh" sets "set -e" which
# causes the script fail on old RH systems where "unset CDPATH" returns non-zero.

CDPATH=dummy \
${RUNTIME_PREFIX}/%{_targetpath}/usr/local/xenomai/kbuild/scripts/prepare-kernel.sh \
%ifarch ppc ppc64
	--arch=powerpc \
	--adeos=${RUNTIME_PREFIX}/%{_targetpath}/usr/local/xenomai/kbuild/ksrc/arch/powerpc/patches/adeos-ipipe-2.6.24-powerpc-DENX-2.1-00.patch \
%else
	--arch=%{_targetarch} \
%ifarch arm
	--adeos=${RUNTIME_PREFIX}/%{_targetpath}/usr/local/xenomai/kbuild/ksrc/arch/arm/patches/adeos-ipipe-2.6.15-arm-1.5-02.patch \
%endif
%endif
	--linux=${RUNTIME_PREFIX}/%{_targetpath}/usr/src/${tree}-xenomai 


%ifarch ppc
%post ppc-kernel

echo "Configuring Xenomai kernel for ARCH=ppc..."
cwd=`pwd`
PATH=${RUNTIME_PREFIX}/usr/bin:$PATH
export PATH

cd ${RUNTIME_PREFIX}/%{_targetpath}/usr/src
tree=`echo linux-2.6.[0-9]*[0-9]`
cp -a ${tree} ${tree}-xenomai-ppc
cd ${tree}-xenomai-ppc
make ARCH=ppc mrproper

# We set CDPATH here because "prepare-kernel.sh" sets "set -e" which
# causes the script fail on old RH systems where "unset CDPATH" returns non-zero.

CDPATH=dummy \
${RUNTIME_PREFIX}/%{_targetpath}/usr/local/xenomai/kbuild/scripts/prepare-kernel.sh \
	--arch=ppc \
	--adeos=${RUNTIME_PREFIX}/%{_targetpath}/usr/local/xenomai/kbuild/ksrc/arch/powerpc/patches/adeos-ipipe-2.6.24-powerpc-DENX-2.1-00.patch
	--linux=${RUNTIME_PREFIX}/%{_targetpath}/usr/src/${tree}-xenomai-ppc

%files ppc-kernel
%endif

%files
%defattr(-,root,root,-)
/usr


%changelog
* Thu Dec 13 2007 Mikhail Cherkashyn <mike@emcraft.com>
- Added ppc-kernel package for ARCH=ppc
* Mon Dec 10 2007 Sergei Poselenov <sposelenov@emcraft.com>
- Updated to 2.4 stable
* Thu Sep 20 2007 Sergei Poselenov <sposelenov@emcraft.com>
- Updated to 2.4-rc3
* Mon Nov 27 2006 Sergei Poselenov <sposelenov@emcraft.com> - 
- Initial build.
